==> rice-dist-2.3.10-src.tar.gz: rice-framework/krad-development-tools/src/test/groovy/org/kuali/rice/krad/devtools/maintainablexml/TestGlobalDetail.java <==
/**
 * Copyright 2005-2016 The Kuali Foundation
 *
 * Licensed under the Educational Community License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.opensource.org/licenses/ecl2.php
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kuali.rice.krad.devtools.maintainablexml;

import org.apache.log4j.Logger;
import org.kuali.rice.krad.bo.GlobalBusinessObjectDetailBase;

/**
 * Business Object representing the account change details entity
 */
public class TestGlobalDetail extends GlobalBusinessObjectDetailBase {

    private static final long serialVersionUID = -6329389744704772474L;
    private static final Logger LOG = Logger.getLogger(TestGlobalDetail.class);

    private String chartOfAccountsCode;
    private String accountNumber;

    // jkeller: made these transient to prevent post processor serialization errors

    /**
     * Default constructor.
     */
    public TestGlobalDetail() {

    }

    public TestGlobalDetail(String chartOfAccountsCode, String accountNumber) {
        this.chartOfAccountsCode = chartOfAccountsCode;
        this.accountNumber = accountNumber;
    }

    /**
     * Gets the chartOfAccountsCode attribute.
     * 
     * @return Returns the chartOfAccountsCode
     */
    public String getChartOfAccountsCode() {
        return chartOfAccountsCode;
    }

    /**
     * Sets the chartOfAccountsCode attribute.
     * 
     * @param chartOfAccountsCode The chartOfAccountsCode to set.
     */
    public void setChartOfAccountsCode(String chartOfAccountsCode) {
        this.chartOfAccountsCode = chartOfAccountsCode;
    }


    /**
     * Gets the accountNumber attribute.
     * 
     * @return Returns the accountNumber
     */
    public String getAccountNumber() {
        return accountNumber;
    }

    /**
     * Sets the accountNumber attribute.
     * 
     * @param accountNumber The accountNumber to set.
     */
    public void setAccountNumber(String accountNumber) {
        this.accountNumber = accountNumber;
    }

}

==> rice-dist-2.5.12-src.tar.gz: rice-framework/krad-development-tools/src/test/groovy/org/kuali/rice/krad/devtools/maintainablexml/TestGlobalDetail.java <==
/**
 * Copyright 2005-2016 The Kuali Foundation
 *
 * Licensed under the Educational Community License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.opensource.org/licenses/ecl2.php
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kuali.rice.krad.devtools.maintainablexml;

import org.apache.log4j.Logger;
import org.kuali.rice.kns.bo.GlobalBusinessObjectDetailBase;

/**
 * Business Object representing the account change details entity
 */
public class TestGlobalDetail extends GlobalBusinessObjectDetailBase {

    private static final long serialVersionUID = -6329389744704772474L;
    private static final Logger LOG = Logger.getLogger(TestGlobalDetail.class);

    private String chartOfAccountsCode;
    private String accountNumber;

    // jkeller: made these transient to prevent post processor serialization errors

    /**
     * Default constructor.
     */
    public TestGlobalDetail() {

    }

    public TestGlobalDetail(String chartOfAccountsCode, String accountNumber) {
        this.chartOfAccountsCode = chartOfAccountsCode;
        this.accountNumber = accountNumber;
    }

    /**
     * Gets the chartOfAccountsCode attribute.
     * 
     * @return Returns the chartOfAccountsCode
     */
    public String getChartOfAccountsCode() {
        return chartOfAccountsCode;
    }

    /**
     * Sets the chartOfAccountsCode attribute.
     * 
     * @param chartOfAccountsCode The chartOfAccountsCode to set.
     */
    public void setChartOfAccountsCode(String chartOfAccountsCode) {
        this.chartOfAccountsCode = chartOfAccountsCode;
    }


    /**
     * Gets the accountNumber attribute.
     * 
     * @return Returns the accountNumber
     */
    public String getAccountNumber() {
        return accountNumber;
    }

    /**
     * Sets the accountNumber attribute.
     * 
     * @param accountNumber The accountNumber to set.
     */
    public void setAccountNumber(String accountNumber) {
        this.accountNumber = accountNumber;
    }

}
